References
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. [Christiansen1974] Christiansen, Freddy Bugge. 1974. “Sufficient Conditions for Protected Polymorphism in a Subdivided Population.” The American Naturalist 108 (960): 157–66.

.. [Christiansen1975] Christiansen, Freddy Bugge. 1975. “Hard and Soft Selection in a Subdivided Population.” The American Naturalist 109 (965): 11–16.

.. [Felsenstein1976] Felsenstein, J. 1976. “The Theoretical Population Genetics of Variable Selection and Migration.” Annual Review of Genetics 10: 253–80.

.. [Haller2019] Haller, B. C., J. Galloway, and J. Kelleher. 2019. “Tree‐sequence Recording in SLiM Opens New Horizons for Forward‐time Simulation of Whole Genomes.” Molecular Ecology. https://onlinelibrary.wiley.com/doi/abs/10.1111/1755-0998.12968.

.. [Jouganous2017] Jouganous, Julien, Will Long, Aaron P. Ragsdale, and Simon Gravel. 2017. “Inferring the Joint Demographic History of Multiple Populations: Beyond the Diffusion Approximation.” Genetics 206 (3): 1549–67.

.. [Kelleher2016] Kelleher, Jerome, Alison M. Etheridge, and Gilean McVean. 2016. “Efficient Coalescent Simulation and Genealogical Analysis for Large Sample Sizes.” PLoS Computational Biology 12 (5): e1004842.

.. [Kelleher2018] Kelleher, Jerome, Kevin R. Thornton, Jaime Ashander, and Peter L. Ralph. 2018. “Efficient Pedigree Recording for Fast Population Genetics Simulation.” PLoS Computational Biology 14 (11): e1006581.

.. [Levene1953] Levene, Howard. 1953. “Genetic Equilibrium When More Than One Ecological Niche Is Available.” The American Naturalist 87 (836): 331–33.
        
.. [Nelson2019]  Nelson, Dominic, Jerome Kelleher, Aaron Ragsdale, Gil McVean, and Simon Gravel. 2019. “Coupling Wright-Fisher and Coalescent Dynamics for Realistic Simulation of Population-Scale Datasets.” bioRxiv. https://doi.org/10.1101/674440.

.. [Ralph2020] Ralph, Peter, Kevin Thornton, and Jerome Kelleher. 2019. “Efficiently Summarizing Relationships in Large Samples: A General Duality between Statistics of Genealogies and Genomes.” bioRxiv. https://doi.org/10.1101/779132.

.. [Song2000] Song, P. 2000 Multivariate dispersion models generated from Gaussian copula. Scandinavian Journal of Statistics 27, 305–320.

